#!/usr/bin/ksh
#
# Xerox Document Centre 432 ST
# Advanced Printing self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V1.0"
KIT_TYPE=$KIT_APS
KIT_PRINTER="Xerox Document Centre 432 ST"
KIT_FILES="Xerox_Document_Centre_432ST_PS.paf"

function setupInstructions {
	print "After the installation script has successfully completed, use the" >&2
	print "/usr/pd/scripts/pd_get_started script or pdprintadmin tool to create" >&2
	print "a new printer and queue." >&2
	print "" >&2
	print "For additional information refer to the Advanced Printing Software" >&2
	print "System Administration and Operation Guide." >&2
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "APX-1-001" /usr/pd/share/cap/Xerox_Document_Centre_432ST_PS.paf 37958 9)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/pd/share/cap/Xerox_Document_Centre_432ST_PS.paf
M(R!0<FEN=&5R($%T=')I8G5T92!&:6QE(&9O<B!897)O>"!$;V-U;65N="!#
M96YT<F4@-#,R+S0T,%-4('!R:6YT97(N"B,@4F5V+B`U+41E8RTR,#`Q"B,*
M(R!#;W!Y<FEG:'0@,C`P,2!#;VUP87$@0V]M<'5T97(@0V]R<&]R871I;VXN
M($%L;"!2:6=H=',@4F5S97)V960N"B,*(R!$;V-U;65N="!#96YT<F4@:7,@
M82!T<F%D96UA<FL@;V8@6&5R;W@@0V]R<&]R871I;VXN"B,@4&]S=%-C<FEP
M="!I<R!A('1R861E;6%R:R!O9B!!9&]B92!3>7-T96US($EN8V]R<&]R871E
M9"X*(PH*<&%F+7@M9FEL92UN86UE/2)897)O>%]$;V-U;65N=%]#96YT<F5?
M-#,R4U1?4%,N<&%F(@IP868M>"UF:6QE+79E<G-I;VX](D%06"TQ+3`P,2(*
M"G!R:6YT97(M;6]D96P](EAE<F]X($1O8W5M96YT($-E;G1R92`T,S(@4U0@
M4%,B"FUA>&EM=6TM<')I;G1E<BUS<&5E9#TS,@H*;F%T:79E+61O8W5M96YT
M+69O<FUA=',M<F5A9'D](E!O<W138W)I<'0B"F1O8W5M96YT+69O<FUA=',M
M<W5P<&]R=&5D/2)0;W-T4V-R:7!T(B`B<VEM<&QE+71E>'0B"F1O8W5M96YT
M+69O<FUA=',M<F5A9'D](E!O<W138W)I<'0B(")S:6UP;&4M=&5X="(*"G!L
M97AE<RUS=7!P;W)T960](G-I;7!L97@B(")D=7!L97@B(")T=6UB;&4B"G-I
M9&5S+7-U<'!O<G1E9#TB,2(@(C(B"G-I9&5S+7)E861Y/2(Q(B`B,B(*"FEN
M<'5T+71R87ES+7-U<'!O<G1E9#TB;6%N=6%L(B`B=&]P(B`B;6%I;B(@(FUI
M9&1L92(@(F)O='1O;2(@(C$B("(R(B`B,R(@(C0B"FEN<'5T+71R87ES+7)E
M861Y/2)M86YU86PB(")T;W`B(")M86EN(B`B;6ED9&QE(B`B8F]T=&]M(B`B
M,2(@(C(B("(S(B`B-"(*"F]U='!U="UB:6YS+7-U<'!O<G1E9#TB=&]P(@IO
M=71P=70M8FEN<RUR96%D>3TB=&]P(@H*<&%F+7-T87)T+7!D;"TQ+6-O;6UA
M;F0](B4A7%PP,3(E)5A26&)E9VEN7%PP,3(E)4])1%]!5%1?4U1!4E1?4TA%
M150@3D].13M<7#`Q,B4E6%)896YD7%PP,3(B"@HC(%-U<&5R=FES;W(@:&EN
M=',*"G!A9BUI<RUP:FP]9F%L<V4*<&%F+6YA=&EV92UD;V-U;65N="UF;W)M
M870M,3TB4&]S=%-C<FEP="(*<&%F+61E9F%U;'0M9&]C=6UE;G0M9F]R;6%T
M/2)0;W-T4V-R:7!T(@IP868M:F]B+7-E<&%R871O<BUF;W)M870](E!O<W13
M8W)I<'0B"@HC(&-O;FYE8W1I;VXM<F5L871E9"!A='1R:6)U=&5S"@IP868M
M8V]N;F5C=&EO;BUL979E;"UP87)A;&QE;#TR"G!A9BUC;VYN96-T:6]N+6QE
M=F5L+6EP+7-O8VME=#TS"G!R:6YT97(M=&-P:7`M<&]R="UN=6UB97(].3$P
M,`H*(R!-961I82!S96QE8W1I;VX*(`HC(%!A9B!!='1R:6)U=&4@("`@("`@
M("!/240@3G5M8F5R("`@("`@("`@("`@("`@("`@("!!;&EA<R!.86UE*',I
M(`HC("TM+2TM+2TM+2TM+2TM+2TM+2T@("`M+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM("!?7U]?7U]?7U]?7U]?"B,@<&%F+3$M;65D:6$M8V]M;6%N
M9"`@(#$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XY-2`@($QE='1E<BP@00HC
M('!A9BTR+6UE9&EA+6-O;6UA;F0@("`Q+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ
M,C`N.3<@("!,961G97(L($(*(R!P868M,RUM961I82UC;VUM86YD("`@,2XR
M+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+CDY("`@03,*(R!P868M-"UM961I82UC
M;VUM86YD("`@,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+C$P,2`@030*(R!P
M868M-2UM961I82UC;VUM86YD("`@,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P
M+C$P-2`@5&%B;&]I9`H*,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+CDU/2(@
M/#P@+U!A9V53:7IE(%LV,3(@-SDR72`@+TEM86=I;F="0F]X(&YU;&P@/CX@
M<V5T<&%G961E=FEC92`B"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XY-STB
M(#P\("]086=E4VEZ92!;-SDR(#$R,C1=("]);6%G:6YG0D)O>"!N=6QL(#X^
M('-E='!A9V5D979I8V4@(@HQ+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N.3D]
M(B`\/"`O4&%G95-I>F4@6S@T,B`Q,3DQ72`O26UA9VEN9T)";W@@;G5L;"`^
M/B!S971P86=E9&5V:6-E("(*,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+C$P
M,3TB(#P\("]086=E4VEZ92!;-3DU(#@T,ET@+TEM86=I;F="0F]X(&YU;&P@
M/CX@<V5T<&%G961E=FEC92`B"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XQ
M,#4](B`\/"`O4&%G95-I>F4@6S<Y,B`Q,C(T72`O26UA9VEN9T)";W@@;G5L
M;"`^/B!S971P86=E9&5V:6-E("(*"B,@<&%F+6UE9&EA+6%L:6%S97,*,2XR
M+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+C<Y/2)L971T97(Z,2!A.C$@;&5D9V5R
M.C(@8CHR(&$S.C,@830Z-"!T86)L;VED.C4B"@HC($EN<'5T('1R87D@<V5L
M96-T:6]N"B,*(R!$979I8V4@=')A>2!N86UE("`@("`@("`@("!/240@=')A
M>2!N86UE("`@5')A>2!.=6UB97(@("`@4W1A;F1A<F0O3W!T:6]N86P*(R`M
M+2TM+2TM+2TM+2TM+2TM("`@("`@("`@("`M+2TM+2TM+2TM+2TM("`@+2TM
M+2TM+2TM+2T@("`@+2TM+2TM+2TM+2TM+2TM+2T*(R!">7!A<W,@5')A>2`@
M("`@("`@("`@("`@("!M86YU86P@("`@("`@("`@("`@("`M("`@("`@("`@
M4W1A;F1A<F0*(R!4<F%Y(#$@("`@("`@("`@("`@("`@("`@("!T;W`@("`@
M("`@("`@("`@("`@("`Q("`@("`@("`@4W1A;F1A<F0*(R!4<F%Y(#(@("`@
M("`@("`@("`@("`@("`@("!M86EN("`@("`@("`@("`@("`@("`R("`@("`@
M("`@4W1A;F1A<F0*(R!4<F%Y(#,@("`@("`@("`@("`@("`@("`@("!M:61D
M;&4@("`@("`@("`@("`@("`S("`@("`@("`@4W1A;F1A<F0*(R!4<F%Y(#0@
M("`@("`@("`@("`@("`@("`@("!B;W1T;VT@("`@("`@("`@("`@("`T("`@
M("`@("`@4W1A;F1A<F0*(R!(:6=H($-A<&%C:71Y($9E961E<B`@("`@("!L
M87)G92UC87!A8VET>2`@("`@("`U("`@("`@("`@3W!T:6]N86P*(R!%;G9E
M;&]P92!4<F%Y("`@("`@("`@("`@("!E;G9E;&]P92`@("`@("`@("`@("`M
M("`@("`@("`@3W!T:6]N86P*"B,@<&%F+6EN<'5T+71R87ES+7!O<W-I8FQE
M"C$N,BXX-#`N,3$S-34P+C$N,RXR+C$R,"XX,STB;6%N=6%L('1O<"!M86EN
M(&UI9&1L92!B;W1T;VT@;&%R9V4M8V%P86-I='D@96YV96QO<&4@,2`R(#,@
M-"`U(@H*(R!P868M:6YP=70M=')A>2UA;&EA<V5S"C$N,BXX-#`N,3$S-34P
M+C$N,RXR+C$R,"XT,CTB,3IT;W`@,CIM86EN(#,Z;6ED9&QE(#0Z8F]T=&]M
M(#4Z;&%R9V4M8V%P86-I='DB"@HC($YU;6)E<F5D('1R87D@;F%M97,@87)E
M('-U<'!O<G1E9"!I;B!P9'-P=G(@5C$N,2!A;F0@;&%T97(*"G!A9BUM86YU
M86PM:6YP=70M8V]M;6%N9"TQ/2(@/#PO36%N=6%L1F5E9"!T<G5E/CX@<V5T
M<&%G961E=FEC92`B"G!A9BUT;W`M:6YP=70M8V]M;6%N9"TQ/2(@/#P@+U1R
M87E3=VET8V@@9F%L<V4^/B!S971P86=E9&5V:6-E(#P\("]-86YU86Q&965D
M(&9A;'-E/CX@<V5T<&%G961E=FEC92`\/"`O365D:6%0;W-I=&EO;B`Q(#X^
M('-E='!A9V5D979I8V4@/#P@+TUE9&EA5'EP92`H56YS<&5C:69I960I(#X^
M('-E='!A9V5D979I8V4@/#P@+TUE9&EA0V]L;W(@*%5N<W!E8VEF:65D*2`^
M/B!S971P86=E9&5V:6-E("(*<&%F+6UA:6XM:6YP=70M8V]M;6%N9"TQ/2(@
M/#P@+U1R87E3=VET8V@@9F%L<V4^/B!S971P86=E9&5V:6-E(#P\("]-86YU
M86Q&965D(&9A;'-E/CX@<V5T<&%G961E=FEC92`\/"`O365D:6%0;W-I=&EO
M;B`R(#X^('-E='!A9V5D979I8V4@/#P@+TUE9&EA5'EP92`H56YS<&5C:69I
M960I(#X^('-E='!A9V5D979I8V4@/#P@+TUE9&EA0V]L;W(@*%5N<W!E8VEF
M:65D*2`^/B!S971P86=E9&5V:6-E("(*<&%F+6UI9&1L92UI;G!U="UC;VUM
M86YD+3$](B`\/"`O5')A>5-W:71C:"!F86QS93X^('-E='!A9V5D979I8V4@
M/#P@+TUA;G5A;$9E960@9F%L<V4^/B!S971P86=E9&5V:6-E(#P\("]-961I
M85!O<VET:6]N(#,@/CX@<V5T<&%G961E=FEC92`\/"`O365D:6%4>7!E("A5
M;G-P96-I9FEE9"D@/CX@<V5T<&%G961E=FEC92`\/"`O365D:6%#;VQO<B`H
M56YS<&5C:69I960I(#X^('-E='!A9V5D979I8V4@(@IP868M8F]T=&]M+6EN
M<'5T+6-O;6UA;F0M,3TB(#P\("]4<F%Y4W=I=&-H(&9A;'-E/CX@<V5T<&%G
M961E=FEC92`\/"`O36%N=6%L1F5E9"!F86QS93X^('-E='!A9V5D979I8V4@
M/#P@+TUE9&EA4&]S:71I;VX@-"`^/B!S971P86=E9&5V:6-E(#P\("]-961I
M851Y<&4@*%5N<W!E8VEF:65D*2`^/B!S971P86=E9&5V:6-E(#P\("]-961I
M84-O;&]R("A5;G-P96-I9FEE9"D@/CX@<V5T<&%G961E=FEC92`B"G!A9BUL
M87)G92UC87!A8VET>2UI;G!U="UC;VUM86YD+3$](B`\/"`O5')A>5-W:71C
M:"!F86QS93X^('-E='!A9V5D979I8V4@/#P@+TUA;G5A;$9E960@9F%L<V4^
M/B!S971P86=E9&5V:6-E(#P\("]-961I85!O<VET:6]N(#4@/CX@<V5T<&%G
M961E=FEC92`\/"`O365D:6%4>7!E("A5;G-P96-I9FEE9"D@/CX@<V5T<&%G
M961E=FEC92`\/"`O365D:6%#;VQO<B`H56YS<&5C:69I960I(#X^('-E='!A
M9V5D979I8V4@(@IP868M96YV96QO<&4M:6YP=70M8V]M;6%N9"TQ/2(@/#P@
M+U1R87E3=VET8V@@9F%L<V4^/B!S971P86=E9&5V:6-E(#P\("]-86YU86Q&
M965D(&9A;'-E/CX@<V5T<&%G961E=FEC92`\/"`O365D:6%0;W-I=&EO;B`Q
M(#X^('-E='!A9V5D979I8V4@/#P@+TUE9&EA5'EP92`H56YS<&5C:69I960I
M(#X^('-E='!A9V5D979I8V4@/#P@+TUE9&EA0V]L;W(@*%5N<W!E8VEF:65D
M*2`^/B!S971P86=E9&5V:6-E("(*"B,@3W5T<'5T(&)I;B!S96QE8W1I;VX*
M("`*(R!$979I8V4@8FEN(&YA;65S("`@("`@("`@("`@("!/240@8FEN(&YA
M;65S("`@0FEN($YU;6)E<G,@("`@4W1A;F1A<F0O3W!T:6]N86P*(R`M+2TM
M+2TM+2TM+2TM+2TM("`@("`@("`@("`@("`M+2TM+2TM+2TM+2TM("`@+2TM
M+2TM+2TM+2T@("`@+2TM+2TM+2TM+2TM+2TM+2T*(R!4;W`@5')A>2`@("`@
M("`@("`@("`@("`@("`@("!T;W`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@4W1A;F1A<F0*(R!&:6YI<VAE<B`@("`@("`@("`@("`@("`@("`@("!S
M=&%C:V5R("`@("`@("`@("`@("`@("`@("`@("`@3W!T:6]N86P*(R!3:61E
M(%1R87D@("`@("`@("`@("`@("`@("`@("!S:61E("`@("`@("`@("`@("`@
M("`@("`@("`@("`@3W!T:6]N86P*(PHC(%1H92!F;VQL;W=I;F<@;F%M97,@
M87)E('-U<'!O<G1E9"!I;B!P9'-P=G(@5C$N,2!A;F0@;&%T97(*(PHC($UA
M:6QB;W@@,2`@("`@("`@("`@("`@("`@("`@(&UA:6QB;W@M,2`@("`@("`@
M("`Q("`@("`@("`@("!/<'1I;VYA;`HC($UA:6QB;W@@,B`@("`@("`@("`@
M("`@("`@("`@(&UA:6QB;W@M,B`@("`@("`@("`R("`@("`@("`@("!/<'1I
M;VYA;`HC($UA:6QB;W@@,R`@("`@("`@("`@("`@("`@("`@(&UA:6QB;W@M
M,R`@("`@("`@("`S("`@("`@("`@("!/<'1I;VYA;`HC($UA:6QB;W@@-"`@
M("`@("`@("`@("`@("`@("`@(&UA:6QB;W@M-"`@("`@("`@("`T("`@("`@
M("`@("!/<'1I;VYA;`HC($UA:6QB;W@@-2`@("`@("`@("`@("`@("`@("`@
M(&UA:6QB;W@M-2`@("`@("`@("`U("`@("`@("`@("!/<'1I;VYA;`HC($UA
M:6QB;W@@-B`@("`@("`@("`@("`@("`@("`@(&UA:6QB;W@M-B`@("`@("`@
M("`V("`@("`@("`@("!/<'1I;VYA;`HC($UA:6QB;W@@-R`@("`@("`@("`@
M("`@("`@("`@(&UA:6QB;W@M-R`@("`@("`@("`W("`@("`@("`@("!/<'1I
M;VYA;`HC($UA:6QB;W@@."`@("`@("`@("`@("`@("`@("`@(&UA:6QB;W@M
M."`@("`@("`@("`X("`@("`@("`@("!/<'1I;VYA;`HC($UA:6QB;W@@.2`@
M("`@("`@("`@("`@("`@("`@(&UA:6QB;W@M.2`@("`@("`@("`Y("`@("`@
M("`@("!/<'1I;VYA;`HC($UA:6QB;W@@,3`@("`@("`@("`@("`@("`@("`@
M(&UA:6QB;W@M,3`@("`@("`@(#$P("`@("`@("`@("!/<'1I;VYA;`H*(R!P
M868M;W5T<'5T+6)I;G,M<&]S<VEB;&4*,2XR+C@T,"XQ,3,U-3`N,2XS+C(N
M,3(P+C@T/2)T;W`@<VED92!S=&%C:V5R+3$@;6%I;&)O>"TQ(&UA:6QB;W@M
M,B!M86EL8F]X+3,@;6%I;&)O>"TT(&UA:6QB;W@M-2!M86EL8F]X+38@;6%I
M;&)O>"TW(&UA:6QB;W@M."!M86EL8F]X+3D@;6%I;&)O>"TQ,"`Q(#(@,R`T
M(#4@-B`W(#@@.2`Q,"`B"@HC('!A9BUO=71P=70M8FEN+6%L:6%S97,*,2XR
M+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+C0S/2(Q.FUA:6QB;W@M,2`R.FUA:6QB
M;W@M,B`S.FUA:6QB;W@M,R`T.FUA:6QB;W@M-"`U.FUA:6QB;W@M-2`V.FUA
M:6QB;W@M-B`W.FUA:6QB;W@M-R`X.FUA:6QB;W@M."`Y.FUA:6QB;W@M.2`Q
M,#IM86EL8F]X+3$P(@H*(R!&:6YI<VAE<B!B:6X*"G!A9BUT;W`M;W5T<'5T
M+6-O;6UA;F0M,3TB(#P\("]/=71P=714>7!E("A4;W!4<F%Y*2`^/B!S971P
M86=E9&5V:6-E("(*<&%F+7-I9&4M;W5T<'5T+6-O;6UA;F0M,3TB(#P\("]/
M=71P=714>7!E("A3:61E5')A>2D@/CX@<V5T<&%G961E=FEC92`B"G!A9BUS
M=&%C:V5R+3$M;W5T<'5T+6-O;6UA;F0M,3TB(#P\("]/=71P=714>7!E("A3
M=&%C:V5R*2`^/B!S971P86=E9&5V:6-E("(*"G!A9BUM86EL8F]X+3$M;W5T
M<'5T+6-O;6UA;F0M,3TB(#P\("]/=71P=714>7!E("A/<'1I;VYA;"!/=71B
M:6X@,BD@/CX@<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X+3(M;W5T<'5T
M+6-O;6UA;F0M,3TB(#P\("]/=71P=714>7!E("A/<'1I;VYA;"!/=71B:6X@
M,RD@/CX@<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X+3,M;W5T<'5T+6-O
M;6UA;F0M,3TB(#P\("]/=71P=714>7!E("A/<'1I;VYA;"!/=71B:6X@-"D@
M/CX@<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X+30M;W5T<'5T+6-O;6UA
M;F0M,3TB(#P\("]/=71P=714>7!E("A/<'1I;VYA;"!/=71B:6X@-2D@/CX@
M<V5T<&%G961E=FEC92`B"G!A9BUM86EL8F]X+34M;W5T<'5T+6-O;6UA;F0M
M,3TB(#P\("]/=71P=714>7!E("A/<'1I;VYA;"!/=71B:6X@-BD@/CX@<V5T
M<&%G961E=FEC92`B"G!A9BUM86EL8F]X+38M;W5T<'5T+6-O;6UA;F0M,3TB
M(#P\("]/=71P=714>7!E("A/<'1I;VYA;"!/=71B:6X@-RD@/CX@<V5T<&%G
M961E=FEC92`B"G!A9BUM86EL8F]X+3<M;W5T<'5T+6-O;6UA;F0M,3TB(#P\
M("]/=71P=714>7!E("A/<'1I;VYA;"!/=71B:6X@."D@/CX@<V5T<&%G961E
M=FEC92`B"G!A9BUM86EL8F]X+3@M;W5T<'5T+6-O;6UA;F0M,3TB(#P\("]/
M=71P=714>7!E("A/<'1I;VYA;"!/=71B:6X@.2D@/CX@<V5T<&%G961E=FEC
M92`B"G!A9BUM86EL8F]X+3DM;W5T<'5T+6-O;6UA;F0M,3TB(#P\("]/=71P
M=714>7!E("A/<'1I;VYA;"!/=71B:6X@,3`I(#X^('-E='!A9V5D979I8V4@
M(@IP868M;6%I;&)O>"TQ,"UO=71P=70M8V]M;6%N9"TQ/2(@/#P@+T]U='!U
M=%1Y<&4@*$]P=&EO;F%L($]U=&)I;B`Q,2D@/CX@<V5T<&%G961E=FEC92`B
M"@HC($]T:&5R($]P=&EO;G,*"B,@<&%F+69I;FES:&EN9W,M<&]S<VEB;&4*
M,2XR+C@T,"XQ,3,U-3`N,2XS+C(N,3(P+C$Q-STB<W1A<&QE('-T87!L92UT
M;W`M;&5F="(*"B-;3F]T95T*(UL@5&AI<R!P<FEN=&5R('-U<'!O<G1S(&%N
M(&]P=&EO;F%L('-T87!L97(@86YD('-T86-K97(@9FEN:7-H:6YG('5N:70*
M(UL@8V%P86)L92!O9B!M86MI;F<@;75L=&EP;&4@;W)I9VEN86P@9&]C=6UE
M;G0@8V]P:65S("AM;W!I97,I+@HC6R!4;R!E;F%B;&4@=&AE(&]P=&EO;F%L
M('-T87!L97(@<V5T"B-;(#QT=#YF:6YI<VAI;F=S+7-U<'!O<G1E9#TB<W1A
M<&QE('-T87!L92UT;W`M;&5F="(\+W1T/@HC6R!O;B!T:&4@;&]G:6-A;"!A
M;F0@<&AY<VEC86P@<')I;G1E<G,L(&%N9`HC6R`\='0^9FEN:7-H:6YG<RUR
M96%D>3TB<W1A<&QE('-T87!L92UT;W`M;&5F="(\+W1T/@HC6R!O;B!T:&4@
M<&AY<VEC86P@<')I;G1E<B!O8FIE8W0N("`*(UM%;F1.;W1E70HC6TYO=&5=
M"B-;(%1H:7,@<')I;G1E<B!A<'!L:65S(&9I;FES:&EN9R!F96%T=7)E<R!B
M>2!J;V(L(&YO="!B>2!D;V-U;65N=',N"B-;(%-P96-I9GEI;F<@=&AE('-T
M87!L92!A='1R:6)U=&4@;VX@82!P<FEN="!R97%U97-T(&-O;G1A:6YI;F<@
M;75L=&EP;&4@"B-;(&1O8W5M96YT<R!W:6QL(')E<W5L="!I;B!A;&P@=&AE
M(&1O8W5M96YT<R!B96EN9R!S=&%P;&5D('1O9V5T:&5R+@HC6R!4;R!S:6YG
M;&4@<W1A<&QE(&$@:F]B('-P96-I9GD@/'1T/F9I;FES:&EN9SUS=&%P;&4\
M+W1T/B!O<B`*(UL@/'1T/F9I;FES:&EN9RUS=&%P;&4M=&]P+6QE9G0\+W1T
M/B!W:71H('1H92!P<FEN="!R97%U97-T+@HC6T5N9$YO=&5="@HC('!A9BUS
M=&%P;&4M=&]P+6QE9G0M9&]C+6-O;6UA;F0*(R!!<W-U;65S(&)A;FYE<B!P
M86=E(&ES(&%L<V\@<')I;G1E9`HQ+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N
M-S,](B`\/"`O4W1A<&QE(#,@/CX@<V5T<&%G961E=FEC92`B"@HC6TYO=&5=
M"B-;(%1O(&UA:V4@;75L=&EP;&4@<W1A<&QE9"!C;W!I97,@;V8@82!D;V-U
M;65N="!U<V4@=&AE(&-O<'DM8V]U;G0@"B-;(&%T=')I8G5T92P@;F]T(&IO
M8BUC;W!I97,L('=H96X@<W5B;6ET=&EN9R!A('!R:6YT(&IO8BX@5&\@9&ES
M86)L90HC6R!M=6QT:7!L92!C;W!Y(&UO9&4@<V5T(#QT=#YP<FEN=&5R+6UU
M;'1I<&QE+6-O<'DM;6]D93UN;SPO='0^+@HC6T5N9$YO=&5="@HC('!R:6YT
M97(M;75L=&EP;&4M8V]P>2UM;V1E/7EE<PHQ+C,N,3(N,BXQ,#$Q+C0N,RXS
M+C(N-3(]>65S"@HC('!A9BUD;V,M8V]P:65S+6-O;6UA;F0*,2XS+C$R+C(N
M,3`Q,2XT+C,N,RXR+C$R,"XQ,3TB(#P\+TYU;4-O<&EE<R`E9"`O0V]L;&%T
M92!T<G5E/CX@<V5T<&%G961E=FEC95Q<,#$R(@H*(R!3:61E<R!S96QE8W1I
M;VX*"G!A9BUS970M<VEM<&QE>"UC;VUM86YD+3$](B`\/"]$=7!L97@@9F%L
M<V4@+U1U;6)L92!F86QS93X^('-E='!A9V5D979I8V4@(@IP868M<V5T+61U
M<&QE>"UC;VUM86YD+3$](B`\/"]$=7!L97@@=')U92`O5'5M8FQE(&9A;'-E
M/CX@<V5T<&%G961E=FEC92`B"G!A9BUS970M='5M8FQE+6-O;6UA;F0M,3TB
M(#P\+T1U<&QE>"!T<G5E("]4=6UB;&4@=')U93X^('-E='!A9V5D979I8V4@
)(@H*(R!%;F0*
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/pd/share/cap/Xerox_Document_Centre_432ST_PS.paf 37958 9
fi

exit 0
